<?php
/**
 * htf_com_func.inc
 *
 * HTF共通関数保有ファイル
 *
 * @package HtmlTemplateFramework
 * @subpackage common
 * @access  public
 * @author    Yamauchi Shogo <htf@as-prj.com>
 * @version $Id: htf_com_func.inc ,v 1.0 $;
 **/

require_once("htf_com_define.inc");	//共通定数

/**
 * xmlの要素名が比較する要素名と合致するかどうかを返します。

 * htfでは、大文字・小文字を意識しないで比較します。

 * 
 * @access     public
 * @param     string    $elemname  判別する要素名

 * @param     string    $compstr   判別に使用する基準要素名

 * @return    bool
 **/
function htf_comp_xmlelementname($elemname, $compstr) {
	$strnamewk="";
	$strcompwk="";
	
	//引数値チェック
	if (htf_is_existsval($elemname)) {
		$strnamewk=$elemname;
	} else {
		//NULLと空文字は空文字

		$strnamewk="";
	}
	if (htf_is_existsval($compstr)) {
		$strcompwk=$compstr;
	} else {
		//NULLと空文字は空文字

		$strcompwk="";
	}
	//コンペア（大文字・小文字を意識しない）

	if (!strcasecmp($elemname, $compstr)) {
		return TRUE;
	} else {
		return FALSE;
	}
}

/**
 * xmlの属性名が比較する属性名と合致するかどうかを返します。

 * htfでは、大文字・小文字を意識しないで比較します。

 * 
 * @access     public
 * @param     string    $attrname  判別する属性名  
 * @param     string    $compstr   判別に使用する基準属性名  
 * @return    bool
 **/
function htf_comp_xmlattrname($attrname, $compstr) {
	$strnamewk="";
	$strcompwk="";
	
	//引数値チェック
	if (htf_is_existsval($attrname)) {
		$strnamewk=$attrname;
	} else {
		//NULLと空文字は空文字

		$strnamewk="";
	}
	if (htf_is_existsval($compstr)) {
		$strcompwk=$compstr;
	} else {
		//NULLと空文字は空文字

		$strcompwk="";
	}
	//コンペア（大文字・小文字を意識しない）

	if (!strcasecmp($attrname, $compstr)) {
		return TRUE;
	} else {
		return FALSE;
	}
}

/**
 * xmlの属性値が比較する属性値と合致するかどうかを返します。

 * htfでは、大文字・小文字を意識しないで比較します。

 * 
 * @access     public
 * @param     string    $attrvalue  判別する属性値  
 * @param     string    $compstr    判別に使用する基準属性値  
 * @return    bool
 **/
function htf_comp_property($attrvalue, $compstr) {
	$strvaluewk="";
	$strcompwk="";
	
	//引数値チェック
	if (htf_is_existsval($attrvalue)) {
		$strvaluewk=$attrvalue;
	} else {
		//NULLと空文字は空文字

		$strvaluewk="";
	}
	if (htf_is_existsval($compstr)) {
		$strcompwk=$compstr;
	} else {
		//NULLと空文字は空文字

		$strcompwk="";
	}
	//コンペア（大文字・小文字を意識しない）

	if (!strcasecmp($attrvalue, $compstr)) {
		return TRUE;
	} else {
		return FALSE;
	}
}

/**
 * 値がhtfで使用できる値かどうかを返します。

 * NULL値や空文字の場合はfalseを返します。

 * 
 * @access     public
 * @param     mixed     $propval  
 * @param     string    $compstr    判別に使用する基準属性値  
 * @return    bool
 **/
function htf_is_existsval($propval) {
	if (is_null($propval)) {
		//NULLはFALSE
		return FALSE;
	} else if (is_string($propval) && $propval == "") {
		//空文字はFALSE（文字型の場合のみ）

		return FALSE;
	}
	return TRUE;
}

/**
 * 引数文字列の最終文字が改行コードかどうかを判別し、

 * 改行コードでない場合には改行コードを付加します。

 * NULL値は空文字の場合には改行コードは付加しません。

 * 
 * @access     public
 * @param     string    $stradd   改行コードを追加する文字列  
 * @return    string
 **/
function htf_add_cr($stradd) {
	//NULLや空文字は空文字を返す
	if (!htf_is_existsval($stradd)) {
		return "";
	}
	//最終文字が改行コードかどうかチェックして返す
	if (strrchr($stradd,"\n") == "\n") {
		$strret = $stradd;
	} else {
		$strret = $stradd."\n";
	}
	return $strret;
}

/**
 * 開始行コメント文字列を作成します。

 * 
 * @access     public
 * @param     string    $strareaname  コメント文字列に組み込むエリア名  
 * @return    string
 **/
function htf_get_comment_areastart($strareaname="") {
	$strret = "";
	if(htf_is_existsval($strareaname)) {
		$strret = '<!-- '.$strareaname.' start -->';
	} else {
		$strret = "<!-- start -->";
	}
	$strret = htf_add_cr($strret);
	return $strret;
}

/**
 * 終了行コメント文字列を作成します。

 * 
 * @access     public
 * @param     string    $strareaname  コメント文字列に組み込むエリア名  
 * @return    string
 **/
function htf_get_comment_areaend($strareaname="") {
	$strret = "";
	if(htf_is_existsval($strareaname)) {
		$strret = '<!-- '.$strareaname.' end -->';
	} else {
		$strret = '<!-- end -->';
	}
	$strret = htf_add_cr($strret);
	return $strret;
}

//////////////////////////////////////
//URL操作関数
//////////////////////////////////////
/**
 * ルートURLとそれ以下を結合し、URL絶対パスを生成する。

 * ルートURLの最後の文字・子URLの先頭文字は、'/'
 * であるかどうかを判別して結合する。

 * 
 * @access     public
 * @param     string    $strroot  ルートURL  
 * @param     string    $strchild ルート以下の子URL  
 * @return    string
 **/
function htf_make_url($strroot, $strchild) {
	if (!htf_is_existsval($strroot)) {
		//rootが指定なし

		return htf_nz($strchild, "");
	} elseif (!htf_is_existsval($strchild)) {
		//childが指定なし

		return $strroot;
	}
	
	//セパレータをつけるかどうか判断して絶対パスを作成して返す
	if (substr($strroot,strlen($strroot)-1,1) == "/") {
		if (substr($strchild, 0, 1) == "/") {
			//ルートの最後が'/'かつ子の先頭も'/'の場合

			return substr($strroot, 0, strlen($strroot)-1).$strchild;
		} else {
			//ルートの最後が'/'かつ子の先頭は'/'でない場合

			return $strroot.$strchild;
		}
	} else {
		if (substr($strchild, 0, 1) == "/") {
			//ルートの最後が'/'でなく、かつ子の先頭が'/'の場合

			return $strroot.$strchild;
		} else {
			//ルートの最後が'/'でなく、かつ子の先頭も'/'でない場合

			return $strroot."/".$strchild;
		}
	}
}

//////////////////////////////////////
//ファイルシステム操作関数
//////////////////////////////////////
/**
 * ディレクトリ名とファイル名を結合し、ファイルシステム上の絶対パスを生成します。

 * ディレクトリ名のの最後の文字はファイル区切り文字であるかどうかを判別して結合します。

 * 
 * @access     public
 * @param     string    $strdir   ディレクトリ名  
 * @param     string    $strchild ファイル名  
 * @return    string
 **/
function htf_make_fullpathname($strdir, $strfname) {
	//引数がNULL・空文字時は空文字を返す
	if (!htf_is_existsval($strdir) || !htf_is_existsval($strfname)) {
		return "";
	}
	//セパレータをつけるかどうか判断して絶対パスを作成して返す
	if (substr($strdir,strlen($strdir)-1,1) == DIRECTORY_SEPARATOR) {
		return $strdir.$strfname;
	} else {
		return $strdir.DIRECTORY_SEPARATOR.$strfname;
	}
}

/**
 * PHP環境設定値のinclude_path内容を引数に指定した配列に取得します。

 * 
 * @access     public
 * @param     array     $arset  include_path内容設定配列  
 * @return    void
 **/
function htf_get_incdirarray(&$arset) {
	$strincpath = get_include_path();
	$pos=0;
	$i=0;
	while($pos<strlen($strincpath) && !is_bool($pos)) {
		$poswk = strpos($strincpath,PATH_SEPARATOR,$pos+1);
		if (!is_bool($poswk)) {
			$arset[$i] = substr($strincpath,$pos,$poswk-$pos);
			$pos=$poswk+1;
		} else {
			$arset[$i] = substr($strincpath,$pos);
			return;
		}
		$i++;
	}
}

/**
 * 引数文字列の最終文字がファイル区切り文字の場合、

 * 最後のファイル区切り文字を削除した文字列を返します。

 * 
 * @access     public
 * @param     string     $strdir  ディレクトリ名

 * @return    string
 **/
function htf_cut_dirseparator($strdir) {
	$strret="";
	//引数がNULL・空文字時は空文字を返す
	if (!htf_is_existsval($strdir)) {
		return "";
	}
	//セパレータ削除を判断して返す
	if ($strdir == DIRECTORY_SEPARATOR) {
		$strret = $strdir;
	} else if (substr($strdir,strlen($strdir)-1,1) == DIRECTORY_SEPARATOR) {
		$strret = substr($strdir,0,strlen($strdir)-1);
	} else {
		$strret = $strdir;
	}
	return $strret;
}

/**
 * 引数ディレクトリ文字列の一つ上のディレクトリ名を返します。

 * 引数ディレクトリがドキュメントルートや、ルートディレクトリを

 * あらわしている場合には、空文字を返します。

 * 
 * @access     public
 * @param     string     $strdir  ディレクトリ名  
 * @return    string
 **/
function htf_get_parentdir($strdir) {
	$strrootdir="";
	$strdirwk="";
	$numpos=0;
	$strret="";

	/////////////////////////////////////////////////////////
	//引数のディレクトリとドキュメントルートの形式をあわせる
	/////////////////////////////////////////////////////////
	//最後尾のディレクトリセパレータをカット
	$strdirwk = htf_cut_dirseparator($strdir);
	//ドキュメントルートのセパレータを変換して最後尾をカット
	$strdirsep = DIRECTORY_SEPARATOR;
	$strrootdir = $_SERVER["DOCUMENT_ROOT"];
	if (!strncasecmp(substr(PHP_OS,0,3),'win',3)) {
		$strrootdir  = str_replace('/',$strdirsep,$strrootdir);
	}
	$strrootdir = htf_cut_dirseparator($strrootdir);
	/////////////////////////////////////////////////////////
	//ドキュメントルートと同じ場合はそこで終了

	/////////////////////////////////////////////////////////
	if (!strcasecmp($strrootdir ,$strdirwk)) {
		return "";
	}
	/////////////////////////////////////////////////////////
	//親ディレクトリの名称を作成
	/////////////////////////////////////////////////////////
	$numpos = strrpos($strdirwk, $strdirsep);
	if (is_bool($numpos)) {
		//エラーの場合

		return "";
	} else if ($numpos == 0) {
		//先頭が見つかった場合

		if ($strdir == $strdirsep) {
			//先頭が渡されていた場合

			return "";
		} else {
			//本当に一つ上がルートだった場合

			return substr($strdirwk,0,1);
		}
	} else if ($numpos >= 0) {
		//その他見つかった場合

		return substr($strdirwk,0,$numpos);
	}
}

/**
 * 指定ファイル名でインクルードパスをサーチし、

 * 存在する場合には絶対パスを返します。

 * 存在しない場合には空文字を返します。

 * 
 * @access     public
 * @param     string     $strfname  ファイル名  
 * @return    string
 **/
function htf_get_fileincludepath($strfname) {
	$ardir=array();
	$strret = htf_get_incdirarray($ardir);
	for ($i=0;$i<count($ardir);$i++) {
		$strfret = htf_make_fullpathname($ardir[$i], $strfname);
		if (file_exists($strfret)) {
			return $strfret;
		}
	}
	return "";
}


/**
 * 指定ファイル名で指定ディレクトリの上位を検索し、

 * 存在する場合には絶対パスを返します。

 * 存在しない場合には空文字を返します。

 * 上位ディレクトリにドキュメントルートが存在する場合には、

 * ドキュメントルートまでで検索を終了します。

 * 
 * @access     public
 * @param     string     $strcwd  ディレクトリ名  
 * @param     string     $strfname  ファイル名  
 * @return    string
 **/
function htf_get_filepath($strcwd, $strfname) {
	$strcwd_wk="";
	$strfret="";
	
	//引数チェック
	if (!htf_is_existsval($strcwd) || !htf_is_existsval($strfname)) {
		return "";
	}
	
	//初期値のフルパス名作成
	$strcwd_wk = $strcwd;
	$strfret = htf_make_fullpathname($strcwd_wk, $strfname);
	//カレントディレクトリに存在した
	if (file_exists($strfret)) {
		return $strfret;
	}

	//上位ディレクトリを順にサーチ

	while ($strcwd_wk != "") {
		//親ディレクトリ名を取得する

		$strcwd_wk = htf_get_parentdir($strcwd_wk);
		if ($strcwd_wk == "") {
			return "";
		}
		$strfret = htf_make_fullpathname($strcwd_wk, $strfname);
		if (file_exists($strfret)) {
			return $strfret;
		}
	}
}

/**
 * 指定ファイル名で指定ディレクトリの上位を検索し、

 * 存在する場合には指定ディレクトリからの相対パスを返します。

 * 存在しない場合には空文字を返します。

 * 上位ディレクトリにドキュメントルートが存在する場合には、

 * ドキュメントルートで検索を終了します。

 * 
 * @access     public
 * @param     string     $strcwd  ディレクトリ名  
 * @param     string     $strfname  ファイル名  
 * @return    string
 **/
function htf_get_filepath_relative($strcwd, $strfname) {
	$strcwd_wk="";
	$strfull="";
	$strfret="";
	
	//引数チェック
	if (!htf_is_existsval($strcwd) || !htf_is_existsval($strfname)) {
		return "";
	}

	//初期値のフルパス名作成
	$strcwd_wk = $strcwd;
	$strfull = htf_make_fullpathname($strcwd_wk, $strfname);
	//カレントディレクトリに存在した
	if (file_exists($strfull)) {
		return $strfname;
	}

	//上位ディレクトリを順にサーチ

	while ($strcwd_wk != "") {
		//親ディレクトリ名を取得する

		$strcwd_wk = htf_get_parentdir($strcwd_wk);
		if ($strcwd_wk == "") {
			return "";
		}
		$strfull = htf_make_fullpathname($strcwd_wk, $strfname);
		$strfret.="..".DIRECTORY_SEPARATOR;
		if (file_exists($strfull)) {
			return $strfret.=$strfname;
		}
	}
}

/**
 * 指定ファイル名の拡張子を指定拡張子にて変更します。

 * 拡張子を引数指定しない場合には、拡張子が削除されます。

 * 
 * @access     public
 * @param     string     $strfname  ファイル名  
 * @param     string     $strext    拡張子名  
 * @return    string
 **/
function htf_change_ext($strfname, $strext="") {
	//引数チェック
	if (!htf_is_existsval($strfname)) {
		return "";
	}
	//後方から最初の.を探す

	$pos=strrpos($strfname,'.');
	if (!$pos) {
		//見つからなかった場合はそのまま
		$strnoext=$strfname;
	} else {
		//見つかった場合はファイル名を切り出し

		$strnoext=substr($strfname,0,$pos);
	}
	//ファイル名作成
	$strret=$strnoext;
	if (htf_is_existsval($strext)) {
		$strret.='.';
		$strret.=$strext;
	}
	
	return $strret;

}

//////////////////////////////////////
//その他

//////////////////////////////////////
/**
 * 指定値がNULLだった場合に指定代替値を返し、NULL値を回避します。

 * 
 * @access     public
 * @param     mixed     $chkparam  NULL値をチェックするパラメータ  
 * @param     mixed     $altval    NULLだった場合に返す代替値
 * @return    mixed
 **/
function htf_nz($chkparam, $altval) {
	if (is_null($chkparam)) {
		return $altval;
	} else {
		return $chkparam;
	}
}

/**
 * 指定した文字列を指定したデリミタで配列に分解します。

 * 
 * @access     public
 * @param     string    $strsplit  分解する文字列  
 * @param     string    $strdelim  判別するデリミタ
 * @return    array
 **/
function htf_split_arr($strsplit, $strdelim) {
	//引数チェック
	if (!htf_is_existsval($strsplit)) {
		return NULL;
	}
	//配列に分解
	$arr_ret = NULL;
	$arr_ret[0] = strtok($strsplit, $strdelim);
	$i = 1;
	while($strval=strtok($strdelim)){
		$arr_ret[$i] = $strval;
		$i++;
	}
	return $arr_ret;
}

/**
 * イメージ名をジェネレートします。

 * 
 * @access     public
 * @return    string
 **/
function htf_gen_imgname() {
	static $gencnt;
	
	$gencnt+=1;
	return 'imgname_'.$gencnt;
}

/**
 * アンカーリンクタグを生成します。

 * 
 * @access     public
 * @param     string    $url  リンク先のURL  
 * @param     string    $disp 表示文字列  
 * @return    string
 **/
function htf_printphplink($url, $disp)
{
	print('<a href="'.$url.'">'.$disp.'</a>');
}

/**
 * 属性指定付きアンカーリンクタグを生成します。

 * 
 * @access     public
 * @param     string    $url  リンク先のURL  
 * @param     string    $disp 表示文字列  
 * @param     string    $opt  属性指定文字列  
 * @return    string
 **/
function htf_printphplink2($url, $disp, $opt)
{
	if ($opt == NULL || $opt == "") {
		print('<a href="'.$url.'">'.$disp.'</a>');
	} else {
		print('<a href="'.$url.'" '.$opt.'>'.$disp.'</a>');
	}
}
?>
