<?php
/**
 * htf_com_initialize.inc
 *
 * HTF共通初期処理です。frame/data/tlbサブパッケージを使用する場合には、

 * このファイルをインクルードする必要があります。

 *
 * @package HtmlTemplateFramework
 * @subpackage common
 * @access  public
 * @author    Yamauchi Shogo <htf@as-prj.com>
 * @version $Id: htf_com_initialize.inc ,v 1.0 $;
 **/
if (version_compare(PHP_VERSION,'5','>='))
	require_once('domxml-php4-to-php5.php');
require_once("htf_com_define.inc");	//共通定数
require_once("htf_com_func.inc");		//共通関数
require_once("htf_com_conf.phl");		//HTF共通環境設定値クラス

//HTF共通環境設定値のロード

$comconf = new htf_com_conf();

//HTMLタグ・エレメント出力方法（大文字・小文字）

/**
 * html要素名を大文字もしくは小文字どちらで出力するかの定義。

 * 環境設定クラス(htf_com_confクラス)のitemcase_elementメンバの値で決定される。

 **/
if (htf_comp_property($comconf->itemcase_element, HTF_CASE_UPPER)) {
	//大文字出力

	define('HTF_ITEMCASE_ELEMENT', HTF_CASE_UPPER);
} else {
	//小文字出力（デフォルト）

	define('HTF_ITEMCASE_ELEMENT', HTF_CASE_LOWER);
}

//HTMLタグ・アトリビュート出力方法（大文字・小文字）

/**
 * html属性名を大文字もしくは小文字どちらで出力するかの定義。

 * 環境設定クラス(htf_com_confクラス)のitemcase_attributeメンバの値で決定される。

 **/
if (htf_comp_property($comconf->itemcase_attribute, HTF_CASE_UPPER)) {
	//大文字出力

	define('HTF_ITEMCASE_ATTRIBUTE', HTF_CASE_UPPER);
} else {
	//小文字出力（デフォルト）

	define('HTF_ITEMCASE_ATTRIBUTE', HTF_CASE_LOWER);
}

//内部エンコーディングの設定（判別済み）

/**
 * htfの内部エンコーディング定義。

 * 環境設定クラス(htf_com_confクラス)のinternal_encoding_encodeメンバの値で決定される。

 **/
if (htf_comp_property($comconf->internal_encoding_encode, HTF_ENCODE_EUC)) {
	//内部エンコーディングがEUC
	define('HTF_PHP_INTERNAL_ENCODING', HTF_ENCODE_EUC);
} else {
	//内部エンコーディングがUTF-8（デフォルト）

	define('HTF_PHP_INTERNAL_ENCODING', HTF_ENCODE_UTF8);
}

/**
 * htfで使用するイメージパスの定義。

 * 環境設定クラス(htf_com_confクラス)のimagepathメンバの値で決定される。

 **/
define('HTF_IMAGEPATH', $comconf->imagepath);

/**
 * htfで使用するCSSパスの定義。

 * 環境設定クラス(htf_com_confクラス)のcsspathメンバの値で決定される。

 **/
define('HTF_CSSPATH',$comconf->csspath);

/**
 * htfで使用するJavaScriptパスの定義。

 * 環境設定クラス(htf_com_confクラス)のjspathメンバの値で決定される。

 **/
define('HTF_JSPATH', $comconf->jspath);

/**
 * htfで使用するルートパスの定義。

 * 環境設定クラス(htf_com_confクラス)のrootpathメンバの値で決定される。

 **/
define('HTF_ROOTPATH', $comconf->rootpath);

/**
 * htfで設定された内部エンコードを判別し、xml属性値を変換します。

 * 内部エンコードはEUC-JPもしくはUTF-8のみ判別します。

 * 
 * @access     public
 * @param     string    $strattr  
 * @return    string
 **/
function htf_get_encoded_attr($strattr) {
	if (!htf_is_existsval($strattr)) {
		//NULLと空文字はそのまま
		return $strattr;
	} else if (!strcasecmp(HTF_PHP_INTERNAL_ENCODING, 'euc-jp')) {
		//内部EUC
		return mb_convert_encoding($strattr, "euc-jp", "UTF-8");
	} else {
		//それ以外

		return $strattr;
	}
}

/**
 * htfで設定された各種パス情報(イメージパス・CSSパス・JavaScriptパス・ルートパス)
 * で引数内の置換タグを変換します。置換タグ定義は次の通り。

 * %HTF_IMAGEPATH%→イメージパス　%HTF_CSSPATH%→CSSパス %HTF_JSPATH%→JavaScriptパス　%HTF_ROOTPATH%→ルートパス
 * 
 * @access     public
 * @param     string    $srcstr  
 * @return    string
 **/
function htf_replace_definetag($srcstr) {
	$repstr1st = str_replace(HTF_REPLACE_HTF_IMAGEPATH, HTF_IMAGEPATH, $srcstr);
	$repstr2nd = str_replace(HTF_REPLACE_HTF_CSSPATH, HTF_CSSPATH, $repstr1st);
	$repstr3rd = str_replace(HTF_REPLACE_HTF_JSPATH, HTF_JSPATH, $repstr2nd);
	$repstr4th = str_replace(HTF_REPLACE_HTF_ROOTPATH, HTF_ROOTPATH, $repstr3rd);
	
	return $repstr4th;
}

?>
